==========
Airmailer
==========


.. image:: https://img.shields.io/pypi/v/airmailer.svg
        :target: https://pypi.python.org/pypi/airmailer

.. image:: https://img.shields.io/travis/cmalek/airmailer.svg
        :target: https://travis-ci.com/cmalek/airmailer

.. image:: https://readthedocs.org/projects/airmailer/badge/?version=latest
        :target: https://airmailer.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


Send e-mails with either plain SMTP or AWS SES.


* Free software: Apache Software License 2.0
* Documentation: https://airmailer.readthedocs.io.

Installation
------------

First, install `airmailer`:

.. code:: bash

   $ pip install airmailer


Documentation
-------------

See https://airmailer.readthedocs.io.
